package com.exxeta.samples.jsr352;

import java.io.File;

import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.csvreader.CsvReader;
import com.exxeta.samples.jsr352.job.ImportJobLauncher;
import com.exxeta.samples.jsr352.model.Person;
import com.exxeta.samples.jsr352.util.BeanProducer;

@RunWith(Arquillian.class)
public class ImportJobTest {

	private static final String WEBINF_SRC = "src/main/webapp/WEB-INF/";
	private static final String BEANS_CFG = "beans.xml";
	private static final String DATASOURCE_CFG = "jsr352-batch-sample-ds.xml";

	@Deployment
    public static Archive<?> createTestArchive() {
		return ShrinkWrap.create(WebArchive.class, "test-import-job.war")
                .addPackage(ImportJobLauncher.class.getPackage())
                .addPackage(BeanProducer.class.getPackage())
                .addPackage(CsvReader.class.getPackage())
                .addPackage(Person.class.getPackage())
                .addAsResource("META-INF/persistence.xml")
                .addAsResource("META-INF/batch-jobs/importJob.xml")
                .addAsWebInfResource(new File(WEBINF_SRC + BEANS_CFG), BEANS_CFG)
                .addAsWebInfResource(new File(WEBINF_SRC + DATASOURCE_CFG), DATASOURCE_CFG);
    }

	@Inject
	private ImportJobLauncher jobLauncher; 

	@PersistenceContext
    private EntityManager entityManager;

	@Test
	public void testCsvImport() throws Exception {
		final long jobId = jobLauncher.createJob(new File("test_data\\contacts.csv"));
		final Query query = entityManager.createNamedQuery("Person.findAll");
		
		jobLauncher.awaitTermination(jobId);
		
		Assert.assertEquals(6, query.getResultList().size());
	}
}
